.. paraphernalia documentation master file, created by
   sphinx-quickstart on Fri Jul  2 18:32:35 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Paraphernalia
=============

Paraphernalia is an assortment of tools for making digital art from
`@joehalliwell <http://twitter.com/joehalliwell>`_.

.. warning::

   This is an incubator for immature scripts/modules with an absolute holy hell of
   dependencies. Mature scripts/modules will likely be packaged more carefully and
   live elsewhere.

User guide
------------------

.. toctree::
   :maxdepth: 1

   installation
   commands
   api

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
